@@ -33,6 +33,7 @@
 #'
 #' @keywords manip
 #' @export
+#' 
 #' @examples
 #'
 #' # keep examples from using more than 2 cores
@@ -69,10 +70,6 @@
 #' 
 colorContrast <- function(m1, m2) {
 
-  # sanity check, need this for color distance eval
-  if(!requireNamespace('farver', quietly = TRUE))
-    stop('please install the `farver` package.', call.=FALSE)
-
   # sanity check: length of colors to compare should be equal
   if(length(m1) != length(m2)) {
     stop('inputs must be the same length', call. = FALSE)
